Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2652)

Unified Diff: chrome/browser/policy/policy_browsertest.cc

Issue 2507073002: Split ArcSessionManager from ArcAuthService. (Closed)
Patch Set: Fix rebase mistake Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/metrics/chromeos_metrics_provider.cc ('k') | chrome/browser/prefs/browser_prefs.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/policy/policy_browsertest.cc
diff --git a/chrome/browser/policy/policy_browsertest.cc b/chrome/browser/policy/policy_browsertest.cc
index 5ff50be2cfcd70d50d18d95b5708fd29c5f2560e..ff9bdf7ccc147d8c4b9e143bb20ab930a92fe5b5 100644
--- a/chrome/browser/policy/policy_browsertest.cc
+++ b/chrome/browser/policy/policy_browsertest.cc
@@ -196,7 +196,7 @@
#include "ash/shell.h"
#include "chrome/browser/chromeos/accessibility/accessibility_manager.h"
#include "chrome/browser/chromeos/accessibility/magnification_manager.h"
-#include "chrome/browser/chromeos/arc/arc_auth_service.h"
+#include "chrome/browser/chromeos/arc/arc_session_manager.h"
#include "chrome/browser/chromeos/login/test/js_checker.h"
#include "chrome/browser/chromeos/system/timezone_resolver_manager.h"
#include "chrome/browser/profiles/profile_manager.h"
@@ -3952,14 +3952,12 @@ class ArcPolicyTest : public PolicyTest {
protected:
void SetUpTest() {
- arc::ArcAuthService::DisableUIForTesting();
+ arc::ArcSessionManager::DisableUIForTesting();
browser()->profile()->GetPrefs()->SetBoolean(prefs::kArcSignedIn, true);
}
- void TearDownTest() {
- arc::ArcAuthService::Get()->Shutdown();
- }
+ void TearDownTest() { arc::ArcSessionManager::Get()->Shutdown(); }
void SetUpInProcessBrowserTestFixture() override {
PolicyTest::SetUpInProcessBrowserTestFixture();
@@ -3977,8 +3975,8 @@ class ArcPolicyTest : public PolicyTest {
}
void SetUpCommandLine(base::CommandLine* command_line) override {
// ArcAuthService functionality is available only when Arc is enabled. Use
// kEnableArc switch that activates it.
command_line->AppendSwitch(chromeos::switches::kEnableArc);
}
« no previous file with comments | « chrome/browser/metrics/chromeos_metrics_provider.cc ('k') | chrome/browser/prefs/browser_prefs.cc » ('j') | no next file with comments »
@@ -3977,8 +3975,8 @@ class ArcPolicyTest : public PolicyTest {
}
void SetUpCommandLine(base::CommandLine* command_line) override {
- // ArcAuthService functionality is available only when Arc is enabled. Use
- // kEnableArc switch that activates it.
+ // ArcSessionManager functionality is available only when Arc is enabled.
+ // Use kEnableArc switch that activates it.
command_line->AppendSwitch(chromeos::switches::kEnableArc);
}

Powered by Google App Engine
This is Rietveld 408576698